@@ -75,7 +75,7 @@ protected:
 	void setGeometry(const TQRect&);
 
 private:
-	int doLayout( const TQRect&, bool testOnly = FALSE );
+	int doLayout( const TQRect&, bool testOnly = false );
 	int doLayoutHorizontal( const TQRect&, bool testOnly );
 	int doLayoutVertical( const TQRect&, bool testOnly );
 	TQt::Orientation mOrientation;
