@@ -30,7 +30,7 @@
  * which is provided by the omnibook kernel module.
  */
 class OmnibookThermalSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
